==> texworks_0.6.1.orig.tar.gz: texworks-release-0.6.1/modules/QtPDF/trans/QtPDF_nn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nn_NO">
<context>
    <name>QtPDF</name>
    <message>
        <source>[language name]</source>
        <translation>Norsk (nynorsk)</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Karl Ove Hufthammer &lt;karl@huftis.org&gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <source>rendering page</source>
        <oldsource>Rendering type</oldsource>
        <translation>teiknar opp side</translation>
    </message>
    <message>
        <source>Unlock PDF</source>
        <oldsource>Unlock Page</oldsource>
        <translation>Lås opp PDF</translation>
    </message>
    <message>
        <source>Please enter the password to unlock the PDF</source>
        <oldsource>Please enter the password to read the document:</oldsource>
        <translation>Skriv inn passordet for å låsa opp PDF-en</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <oldsource>Incorrect password.</oldsource>
        <translation>Feil passord</translation>
    </message>
    <message>
        <source>The password you entered was incorrect.</source>
        <oldsource>Password is incorrect.</oldsource>
        <translation>Du skreiv inn feil passord.</translation>
    </message>
    <message>
        <source>This document is locked. You need a password to open it.</source>
        <translation>Dokumentet er låst. Du treng eit passord for å opna det.</translation>
    </message>
    <message>
        <source>Unlock</source>
        <oldsource>Unlock</oldsource>
        <translation>Lås opp</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <source>Insufficient permission</source>
        <oldsource>Insufficient Permissions</oldsource>
        <translation>Manglar løyve</translation>
    </message>
    <message>
        <source>Text extraction is not allowed for this document.</source>
        <oldsource>This name is not allowed for a document class.</oldsource>
        <translation>Uthenting av tekst er ikkje tillate for dette dokumentet.</translation>
    </message>
    <message>
        <source>Goto page %1</source>
        <oldsource>Go to page %1</oldsource>
        <translation>Gå til side %1</translation>
    </message>
    <message>
        <source>Execute `%1`</source>
        <oldsource>Execute, </oldsource>
        <oldcomment>@item:intext Access permission, concatenated</oldcomment>
        <translation>Køyr «%1»</translation>
    </message>
    <message>
        <source>Table of Contents</source>
        <oldsource>Table of Contents</oldsource>
        <translation>Innhaldsliste</translation>
    </message>
    <message>
        <source>Meta Data</source>
        <oldsource>Meta Data</oldsource>
        <oldcomment>Name</oldcomment>
        <translation>Metadata</translation>
    </message>
    <message>
        <source>Processing</source>
        <oldsource>Processing...</oldsource>
        <translation>Handsamar</translation>
    </message>
    <message>
        <source>Other</source>
        <oldsource>Other</oldsource>
        <oldcomment>@label</oldcomment>
        <translation>Anna</translation>
    </message>
    <message>
        <source>Yes</source>
        <oldsource>Yes</oldsource>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <oldsource>No</oldsource>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Unknown</source>
        <oldsource>Unknown</oldsource>
        <oldcomment>@item:intable</oldcomment>
        <translation>Ukjend</translation>
    </message>
    <message>
        <source>Document</source>
        <oldsource>Document</oldsource>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Title:</source>
        <oldsource>Title:</oldsource>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>Author:</source>
        <oldsource>Author:</oldsource>
        <oldcomment>@item:intable the author will be written here</oldcomment>
        <translation>Forfattar:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <oldsource>Subject:</oldsource>
        <translation>Emne:</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <oldsource>Keywords:</oldsource>
        <translation>Nøkkelord:</translation>
    </message>
    <message>
        <source>Creator:</source>
        <oldsource>Creator:</oldsource>
        <translation>Opphavsprogram:</translation>
    </message>
    <message>
        <source>Producer:</source>
        <oldsource>Producer</oldsource>
        <translation>Produsent:</translation>
    </message>
    <message>
        <source>Creation date:</source>
        <oldsource>Creation date: %1</oldsource>
        <translation>Oppretta:</translation>
    </message>
    <message>
        <source>Modification date:</source>
        <oldsource>Last Modification Time</oldsource>
        <translation>Sist endra:</translation>
    </message>
    <message>
        <source>Trapped:</source>
        <oldsource>Trap</oldsource>
        <translation>Fanga:</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Skrifter</translation>
    </message>
    <message>
        <source>Type 0</source>
        <oldsource>Type 1</oldsource>
        <translation>Type 0</translation>
    </message>
    <message>
        <source>Type 1</source>
        <oldsource>Type 1</oldsource>
        <translation>Type 1</translation>
    </message>
    <message>
        <source>Type 1 (multiple master)</source>
        <translation>Type 1 (Multiple Master)</translation>
    </message>
    <message>
        <source>Type 3</source>
        <oldsource>Type 3</oldsource>
        <translation>Type 3</translation>
    </message>
    <message>
        <source>TrueType</source>
        <oldsource>TrueType</oldsource>
        <translation>TrueType</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nei</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation>[innebygd]</translation>
    </message>
    <message>
        <source>[builtin]</source>
        <oldsource>built-in</oldsource>
        <translation>[innebygd]</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation>Delmengd</translation>
    </message>
    <message>
        <source>Source</source>
        <oldsource>Source</oldsource>
        <translation>Kjelde</translation>
    </message>
    <message>
        <source>Permissions</source>
        <oldsource>Permissions</oldsource>
        <translation>Løyve</translation>
    </message>
    <message>
        <source>Allowed</source>
        <oldsource>A&amp;llowed</oldsource>
        <translation>Tillate</translation>
    </message>
    <message>
        <source>Low resolution only</source>
        <oldsource>&amp;No resolution</oldsource>
        <translation>Berre låg oppløysing</translation>
    </message>
    <message>
        <source>Denied</source>
        <oldsource>Denied users</oldsource>
        <translation>Nekta</translation>
    </message>
    <message>
        <source>Assembling only</source>
        <translation>Berre samansetjing</translation>
    </message>
    <message>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>Set inn, roter eller slett sider og lag bokmerke eller miniatyrbilete av sider</translation>
    </message>
    <message>
        <source>Accessibility support only</source>
        <oldsource>Accessibility Options</oldsource>
        <oldcomment>Comment</oldcomment>
        <translation>Berre tilgjengestøtte</translation>
    </message>
    <message>
        <source>Printing:</source>
        <oldsource>Printing...</oldsource>
        <translation>Utskrift:</translation>
    </message>
    <message>
        <source>Modifications:</source>
        <oldsource>Notifications:</oldsource>
        <translation>Endringar:</translation>
    </message>
    <message>
        <source>Extraction:</source>
        <oldsource>Extraction</oldsource>
        <translation>Tekstuthenting</translation>
    </message>
    <message>
        <source>Annotation:</source>
        <oldsource>Annotations</oldsource>
        <translation>Merknadar:</translation>
    </message>
    <message>
        <source>Filling forms:</source>
        <translation>Utfylling av skjema:</translation>
    </message>
    <message>
        <source>Annotations</source>
        <oldsource>Annotations</oldsource>
        <translation>Merknadar</translation>
    </message>
    <message>
        <source>Page</source>
        <oldsource>Page</oldsource>
        <translation>Side</translation>
    </message>
    <message>
        <source>Subject</source>
        <oldsource>Subject</oldsource>
        <translation>Emne</translation>
    </message>
    <message>
        <source>Author</source>
        <oldsource>Author</oldsource>
        <translation>Forfattar</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Innhald</translation>
    </message>
</context>
</TS>

==> texworks_0.6.2.orig.tar.gz: texworks-release-0.6.2/modules/QtPDF/trans/QtPDF_nn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nn_NO">
<context>
    <name>QtPDF</name>
    <message>
        <source>[language name]</source>
        <translation>Norsk (nynorsk)</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Karl Ove Hufthammer &lt;karl@huftis.org&gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <source>rendering page</source>
        <translation>teiknar opp side</translation>
    </message>
    <message>
        <source>Unlock PDF</source>
        <translation>Lås opp PDF</translation>
    </message>
    <message>
        <source>Please enter the password to unlock the PDF</source>
        <translation>Skriv inn passordet for å låsa opp PDF-en</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Feil passord</translation>
    </message>
    <message>
        <source>The password you entered was incorrect.</source>
        <translation>Du skreiv inn feil passord.</translation>
    </message>
    <message>
        <source>This document is locked. You need a password to open it.</source>
        <translation>Dokumentet er låst. Du treng eit passord for å opna det.</translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation>Lås opp</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <source>Insufficient permission</source>
        <translation>Manglar løyve</translation>
    </message>
    <message>
        <source>Text extraction is not allowed for this document.</source>
        <translation>Uthenting av tekst er ikkje tillate for dette dokumentet.</translation>
    </message>
    <message>
        <source>Goto page %1</source>
        <translation>Gå til side %1</translation>
    </message>
    <message>
        <source>Execute `%1`</source>
        <translation>Køyr «%1»</translation>
    </message>
    <message>
        <source>Table of Contents</source>
        <translation>Innhaldsliste</translation>
    </message>
    <message>
        <source>Meta Data</source>
        <translation>Metadata</translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Handsamar</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Anna</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukjend</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Forfattar:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Emne:</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Nøkkelord:</translation>
    </message>
    <message>
        <source>Creator:</source>
        <translation>Opphavsprogram:</translation>
    </message>
    <message>
        <source>Producer:</source>
        <translation>Produsent:</translation>
    </message>
    <message>
        <source>Creation date:</source>
        <translation>Oppretta:</translation>
    </message>
    <message>
        <source>Modification date:</source>
        <translation>Sist endra:</translation>
    </message>
    <message>
        <source>Trapped:</source>
        <translation>Fanga:</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Skrifter</translation>
    </message>
    <message>
        <source>Type 0</source>
        <translation>Type 0</translation>
    </message>
    <message>
        <source>Type 1</source>
        <translation>Type 1</translation>
    </message>
    <message>
        <source>Type 1 (multiple master)</source>
        <translation>Type 1 (Multiple Master)</translation>
    </message>
    <message>
        <source>Type 3</source>
        <translation>Type 3</translation>
    </message>
    <message>
        <source>TrueType</source>
        <translation>TrueType</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nei</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation>[innebygd]</translation>
    </message>
    <message>
        <source>[builtin]</source>
        <translation>[innebygd]</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation>Delmengd</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Kjelde</translation>
    </message>
    <message>
        <source>Permissions</source>
        <translation>Løyve</translation>
    </message>
    <message>
        <source>Allowed</source>
        <translation>Tillate</translation>
    </message>
    <message>
        <source>Low resolution only</source>
        <translation>Berre låg oppløysing</translation>
    </message>
    <message>
        <source>Denied</source>
        <translation>Nekta</translation>
    </message>
    <message>
        <source>Assembling only</source>
        <translation>Berre samansetjing</translation>
    </message>
    <message>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>Set inn, roter eller slett sider og lag bokmerke eller miniatyrbilete av sider</translation>
    </message>
    <message>
        <source>Accessibility support only</source>
        <translation>Berre tilgjengestøtte</translation>
    </message>
    <message>
        <source>Printing:</source>
        <translation>Utskrift:</translation>
    </message>
    <message>
        <source>Modifications:</source>
        <translation>Endringar:</translation>
    </message>
    <message>
        <source>Extraction:</source>
        <translation>Tekstuthenting:</translation>
    </message>
    <message>
        <source>Annotation:</source>
        <translation>Merknadar:</translation>
    </message>
    <message>
        <source>Filling forms:</source>
        <translation>Skjemautfylling:</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Merknadar</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>Emne</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfattar</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Innhald</translation>
    </message>
</context>
</TS>
